@@ -13,9 +13,7 @@ class StartEvent(Task):
 
         context["status"] = "STARTED"
 
-        context[self.activity_data.get("@name","start")] = {
-            "start_time" : datetime.now(),
-            "end_time" : datetime.now()
-        }
+        self.task_context["start_time"] = datetime.now()
+        self.task_context["end_time"] = datetime.now()
         
         self.process_instance.evaluate_results(self.get_outgoing_activities())
\ No newline at end of file
